======================
Django Account Manager
======================

Experimental implementation of Account Management and Session Identification (see https://wiki.mozilla.org/Labs/Weave/Identity/Account_Manager/Spec/Latest

Documentation
=============

http://forge.2metz.fr/p/django-account-manager/doc/




